CallLogEntry class

PODO for one call log entry

Constructors

CallLogEntry({String? name, String? number, String? formattedNumber, CallType? callType, int? duration, int? timestamp, int? cachedNumberType, String? cachedNumberLabel, String? simDisplayName, String? phoneAccountId})
constructor
CallLogEntry.fromMap(Map m)
constructor creating object from provided map

Properties

cachedMatchedNumber ↔ String?
todo comment
getter/setter pair
cachedNumberLabel ↔ String?
todo comment
getter/setter pair
cachedNumberType ↔ int?
todo comment
getter/setter pair
callType ↔ CallType?
type of call entry. see CallType
getter/setter pair
duration ↔ int?
duration in seconds
getter/setter pair
formattedNumber ↔ String?
formatted number based on phone locales
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
contact name
getter/setter pair
number ↔ String?
contact number
getter/setter pair
phoneAccountId ↔ String?
PHONE account id
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
simDisplayName ↔ String?
SIM display name
getter/setter pair
timestamp ↔ int?
unix timestamp of call start
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited